@@ -77,7 +77,10 @@ load_gpgme_key (const gchar *keyid,
 	gpgme_ctx_t ctx;
 	gpgme_error_t gerr;
 
-	ctx = seahorse_gpgme_keyring_new_context ();
+	ctx = seahorse_gpgme_keyring_new_context (&gerr);
+	if (gerr != 0)
+		return FALSE;
+
 	gpgme_set_keylist_mode (ctx, mode);
 	gerr = gpgme_op_keylist_start (ctx, keyid, secret);
 	if (GPG_IS_OK (gerr)) {
@@ -154,7 +157,7 @@ require_key_private (SeahorseGpgmeKey *self)
 static gboolean
 require_key_uids (SeahorseGpgmeKey *self)
 {
-	return require_key_public (self, GPGME_KEYLIST_MODE_LOCAL | GPGME_KEYLIST_MODE_SIGS);
+	return require_key_public (self, GPGME_KEYLIST_MODE_LOCAL);
 }
 
 static gboolean
@@ -360,6 +363,12 @@ seahorse_gpgme_key_realize (SeahorseGpgmeKey *self)
 	seahorse_pgp_key_realize (SEAHORSE_PGP_KEY (self));
 }
 
+void
+seahorse_gpgme_key_ensure_signatures (SeahorseGpgmeKey *self)
+{
+	require_key_public (self, GPGME_KEYLIST_MODE_LOCAL | GPGME_KEYLIST_MODE_SIGS);
+}
+
 void
 seahorse_gpgme_key_refresh (SeahorseGpgmeKey *self)
 {
